@@ -1,5 +1,5 @@
 package Yahoo::Marketing::ForecastKeywordBatchResponse;
-# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -8,20 +8,15 @@ use base qw/Yahoo::Marketing::ComplexType/;
 
 =head1 NAME
 
-Yahoo::Marketing::ForecastKeywordBatchResponse - an object returns the forecasted results for a given set of keyword and (optional) ad group combination. 
+Yahoo::Marketing::ForecastKeywordBatchResponse - an object to represent a Yahoo Marketing ForecastKeywordBatchResponse.
 
 =cut
 
 sub _user_setable_attributes {
     return ( qw/ 
-             canonKeyword
-             errors
-             forecastLandscape
-             forecastResponseDetail
-             keyword
-             matchTypes
-             operationSucceeded
-             warnings
+                 errors
+                 forecastKeywordBatchResponseData
+                 operationSucceeded
             /  );
 }
 
@@ -38,7 +33,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.
+See L<http://searchmarketing.yahoo.com/developer/docs/V5/reference/dataObjects.php> for documentation of the various data objects.
 
 
 =cut
@@ -53,14 +48,9 @@ Creates a new instance
 
 =over 8
 
-    canonKeyword
     errors
-    forecastLandscape
-    forecastResponseDetail
-    keyword
-    matchTypes
+    forecastKeywordBatchResponseData
     operationSucceeded
-    warnings
 
 =back
 
