@@ -1,5 +1,5 @@
 package Yahoo::Marketing::HistoricalKeywordResponse;
-# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -8,15 +8,15 @@ use base qw/Yahoo::Marketing::ComplexType/;
 
 =head1 NAME
 
-Yahoo::Marketing::HistoricalKeywordResponse - an object provides the historical data for the given keyword, match types and each month in the date range.
+Yahoo::Marketing::HistoricalKeywordResponse - an object to represent a Yahoo Marketing HistoricalKeywordResponse.
 
 =cut
 
 sub _user_setable_attributes {
     return ( qw/ 
-             historicalData
-             keyword
-             matchTypes
+                 errors
+                 historicalKeywordResponseData
+                 operationSucceeded
             /  );
 }
 
@@ -33,7 +33,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.
+See L<http://searchmarketing.yahoo.com/developer/docs/V5/reference/dataObjects.php> for documentation of the various data objects.
 
 
 =cut
@@ -48,9 +48,9 @@ Creates a new instance
 
 =over 8
 
-    historicalData
-    keyword
-    matchTypes
+    errors
+    historicalKeywordResponseData
+    operationSucceeded
 
 =back
 
